@@ -14,9 +14,9 @@
 #  GNU Lesser General Public License for more details.
 #
 #  You should have received a copy of the GNU Lesser General Public License
-#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>
+#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-__version__ = "2.0.140"
+__version__ = "2.0.142"
 __license__ = "GNU Lesser General Public License v3.0 (LGPL-3.0)"
 __copyright__ = "Copyright (C) 2017-present Dan <https://github.com/delivrance>"
 
@@ -35,8 +35,8 @@ class ContinuePropagation(StopAsyncIteration):
     pass
 
 
-from . import emoji, enums, filters, handlers, raw, types
+from . import raw, types, filters, handlers, emoji, enums
 from .client import Client
-from .sync import compose, idle
+from .sync import idle, compose
 
 crypto_executor = ThreadPoolExecutor(1, thread_name_prefix="CryptoWorker")
